``zope.meta``
=============

.. image:: https://img.shields.io/pypi/v/zope.meta.svg
    :target: https://pypi.python.org/pypi/zope.meta/
    :alt: Latest Version

.. image:: https://github.com/zopefoundation/meta/actions/workflows/tests.yml/badge.svg
    :target: https://github.com/zopefoundation/meta/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/meta/badge.svg?branch=master
    :target: https://coveralls.io/github/zopefoundation/meta?branch=master
        
.. image:: https://readthedocs.org/projects/zopemeta/badge/?version=latest
    :target: https://zopemeta.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

This package contains helper functions and scripts for maintaining package
configurations for Zope Foundation GitHub packages
(https://github.com/zopefoundation).

Please visit https://zopemeta.readthedocs.io for the documentation.
